@@ -314,6 +314,18 @@ class DocumentsEndpointGroup(EndpointGroup[data_model.TextDocument]):
             skip:int = 0,
             take:int=50
     ) -> Union[List[data_model.TextDocument],List[data_model.ScoredDocumentResponse]]:
+        """_summary_
+
+        Args:
+            project_id (str): Uuid of project
+            query (Union[DocumentQueryFilter,Or]): Where query to match the documents
+            order_by (str, optional): Sort by field. Defaults to None.
+            skip (int, optional): paging - skip. Defaults to 0.
+            take (int, optional): paging - take. Defaults to 50.
+
+        Returns:
+            Union[List[data_model.TextDocument],List[data_model.ScoredDocumentResponse]]: _description_
+        """
         responseData = self._call_endpoint("POST", f"/projects/{project_id}/doc/query", body=query, query_params={"order_by":order_by, "skip":skip, "take":take},entityClass=dict)
         if responseData and "score" in responseData[0]:
             return [data_model.ScoredDocumentResponse.from_dict(item) for item in responseData  ]
@@ -371,7 +383,7 @@ class DocumentsEndpointGroup(EndpointGroup[data_model.TextDocument]):
         return result
 
 
-    def add_documents(self, project_id:str, data:Union[pandas.DataFrame,List[dict]], upsert:bool=False, batch_size:int=100 )->Union[List[str], None]:
+    def add_documents(self, project_id:str, data:Union[pandas.DataFrame,List[dict]], upsert:bool=False, batch_size:int=100 )->List[dict]:
         """Add documents to project
 
         Args:
@@ -394,16 +406,16 @@ class DocumentsEndpointGroup(EndpointGroup[data_model.TextDocument]):
                 if "text" not in rec:
                     raise Exception("column named 'text' must be present in data")
             documents=data
-
+        
         def send(data):
             return self._call_endpoint("POST", f"/projects/{project_id}/doc", query_params={"upsert":upsert},entityClass=dict,body=data)
 
 
-        ids = []
+        response_data = []
         for batch in tqdm(batchify(documents,batch_size), total=(int(len(documents)/batch_size)),desc="Add documents",unit="batch", delay=2):
             for item in send(batch):
-                ids.append(item)
-        return ids
+                response_data.append(item)
+        return response_data
 
     def exclude(self, project_id:str, doc_ids:List[str])-> None: 
         """Exclude document 
@@ -424,6 +436,21 @@ class DocumentsEndpointGroup(EndpointGroup[data_model.TextDocument]):
         """
         self._call_endpoint("DELETE", f"/projects/{project_id}/doc/{doc_id}", entityClass=None)
 
+    
+    def delete_by_query(self, project_id:str, query:Union[DocumentQueryFilter,Or], wait_for_completion=False)-> None: 
+        """_Delete documents by provided query
+
+        Args:
+            project_id (str): Uuid of project
+            query (Union[DocumentQueryFilter,Or]): query filter to match the documents to be deleted
+            wait_for_completion (bool, optional): Triggers synchronous exectuion. Limits the number of records to be deleted to 10 000 (but can be run in loop until no data remains). Defaults to False.
+
+        Returns:
+            None
+        """
+
+        self._call_endpoint("DELETE", f"/projects/{project_id}/doc/", body=query, query_params={"wait_for_completion":wait_for_completion}, entityClass=None)
+
 
     def delete_all(self, project_id:str)-> None:
         """Bulk delete of all documents in project!
